
## CATO-CLI - query.site.bgpPeer:
[Click here](https://api.catonetworks.com/documentation/#query-query.site.bgpPeer) for documentation on this operation.

### Usage for query.site.bgpPeer:

`catocli query site bgpPeer -h`

`catocli query site bgpPeer <json>`

`catocli query site bgpPeer "$(cat < query.site.bgpPeer.json)"`

`catocli query site bgpPeer '{"bgpPeerRefInput":{"by":"ID","input":"string"}}'`

`catocli query site bgpPeer -p '{
    "bgpPeerRefInput": {
        "by": "ID",
        "input": "string"
    }
}'`


#### Operation Arguments for query.site.bgpPeer ####

`accountId` [ID] - (required) N/A    
`bgpPeerRefInput` [BgpPeerRefInput] - (required) N/A    
